# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ContentBlockTypeStrEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    HTML = 'html'
    BTN = 'btn'
    VIDEO = 'video'
    AUDIO = 'audio'
    PDF = 'pdf'
    QUIZ_TEXT = 'quiz_text'
    QUIZ_VIDEO = 'quiz_video'
    QUIZ_AUDIO = 'quiz_audio'
    CERTIFICATE = 'certificate'

    @classmethod
    def from_json(cls, json_str: str) -> ContentBlockTypeStrEnum:
        """Create an instance of ContentBlockTypeStrEnum from a JSON string"""
        return ContentBlockTypeStrEnum(json.loads(json_str))


