# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from public_api_server_connector.models.category_permissions import CategoryPermissions

class ApiKeyUpdate(BaseModel):
    """
    ApiKeyUpdate
    """
    name: StrictStr = Field(...)
    permissions: Optional[Dict[str, CategoryPermissions]] = Field(default=None, description="Permissions for each category, where the key is the category name and the value is the permissions.")
    __properties = ["name", "permissions"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiKeyUpdate:
        """Create an instance of ApiKeyUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in permissions (dict)
        _field_dict = {}
        if self.permissions:
            for _key in self.permissions:
                if self.permissions[_key]:
                    _field_dict[_key] = self.permissions[_key].to_dict()
            _dict['permissions'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiKeyUpdate:
        """Create an instance of ApiKeyUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiKeyUpdate.parse_obj(obj)

        _obj = ApiKeyUpdate.parse_obj({
            "name": obj.get("name"),
            "permissions": {
                _k: CategoryPermissions.from_dict(_v) for _k, _v in obj["permissions"].items()
            }
            if obj.get("permissions") is not None
            else None
        })
        return _obj


