# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CourseModuleViewTypeStrEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    LIST = 'list'
    GRID = 'grid'

    @classmethod
    def from_json(cls, json_str: str) -> CourseModuleViewTypeStrEnum:
        """Create an instance of CourseModuleViewTypeStrEnum from a JSON string"""
        return CourseModuleViewTypeStrEnum(json.loads(json_str))


